recurring package
=================

Submodules
----------

recurring.admin module
----------------------

.. automodule:: recurring.admin
   :members:
   :undoc-members:
   :show-inheritance:

recurring.apps module
---------------------

.. automodule:: recurring.apps
   :members:
   :undoc-members:
   :show-inheritance:

recurring.forms module
----------------------

.. automodule:: recurring.forms
   :members:
   :undoc-members:
   :show-inheritance:

recurring.models module
-----------------------

.. automodule:: recurring.models
   :members:
   :undoc-members:
   :show-inheritance:

recurring.settings\_test module
-------------------------------

.. automodule:: recurring.settings_test
   :members:
   :undoc-members:
   :show-inheritance:

recurring.utils module
----------------------

.. automodule:: recurring.utils
   :members:
   :undoc-members:
   :show-inheritance:

recurring.widgets module
------------------------

.. automodule:: recurring.widgets
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: recurring
   :members:
   :undoc-members:
   :show-inheritance:
